<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.x-cart.com/license-agreement.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2014 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license   http://www.x-cart.com/license-agreement.html X-Cart 5 License Agreement
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\VitalitySkin;

/**
 * Module description
 *
 * @package XLite
 */
abstract class Main extends \XLite\Module\AModuleSkin
{
    /**
     * Author name
     *
     * @return string
     */
    public static function getAuthorName()
    {
        return 'Qualiteam';
    }

    /**
     * Module name
     *
     * @return string
     */
    public static function getModuleName()
    {
        return 'Template #13 "Vitality"';
    }

    /**
     * Get module major version
     *
     * @return string
     */
    public static function getMajorVersion()
    {
        return '5.3';
    }

    /**
     * Module version
     *
     * @return string
     */
    public static function getMinorVersion()
    {
        return '3';
    }

    /**
     * Module description
     *
     * @return string
     */
    public static function getDescription()
    {
        return 'The "Vitality" X-Cart Design Template (#13). This template is good for the following themes: Exterior design, Medical, Nature, Nutritional supplements.';
    }

     /**
     * Register the module skins.
     *
     * @return array
     */
    public static function getSkins()
    {
        return array(
            \XLite::CUSTOMER_INTERFACE => array(
                'VitalitySkin/customer',
            ),
        );
    }

    public static function getLayoutTypes()
    {
        return array(
            \XLite\Core\Layout::LAYOUT_TWO_COLUMNS_LEFT,
            \XLite\Core\Layout::LAYOUT_TWO_COLUMNS_RIGHT,
        );
    }

    public static function getLayoutColors()
    {
        return array();
    }

    /**
     * Get module build number (4th number in the version)
     *
     * @return string
     */
    public static function getBuildVersion()
    {
        return '3';
    }

    /**
     * Get minor core version which is required for the module activation
     *
     * @return string
     */
    public static function getMinorRequiredCoreVersion()
    {
        return '0';
    }

    /**
     * Determines if some module is enabled
     *
     * @return boolean
     */
    public static function isModuleEnabled($moduleName, $moduleAuthor = 'CDev')
    {
        $module = \XLite\Core\Database::getRepo('XLite\Model\Module')
            ->findOneBy(array('author' => $moduleAuthor, 'name' => $moduleName));
        return $module && $module->getEnabled();
    }

    /**
     *
     * @return array
     */
    protected static function moveClassesInLists()
    {
        $moves = array();

        $moves += array(
            'XLite\View\Form\Product\Search\Customer\Simple' => array(
                'layout.header.bar',
            ),
            /*'XLite\View\Menu\Customer\Top' => array(
                array('layout.main', 'customer'),
                array('layout.main.center.center', 10, 'customer'),
            ),*/
        );

        return $moves;
    }

    /**
     * 
     * @return array
     */
    protected static function moveTemplatesInLists()
    {
        return array(
            'layout/header/top_menu.twig' => array(
                array('layout.main', 'customer'),
            ),
            'layout/header/header.bar.twig' => array(
                array('layout.header', 'customer'),
                array('layout.header', 90, 'customer'),
            ),
            'layout/content/main.location.twig' => array(
                array('layout.main', 'customer'),
                array('layout.main.breadcrumbs', 20, 'customer'),
            ),
            'items_list/product/parts/grid.button-add2cart-wrapper.twig' => array(
                array('itemsList.product.grid.customer.tail', 'customer'),
                array('itemsList.product.grid.customer.info', 600, 'customer'),
            ),
            'product/details/parts/common.product-common-attributes.twig' => array(
                array('product.details.page.tab.description', 'customer'),
                array('product.details.page.info', 23, 'customer'),
            ),
            'product/details/parts/common.product-main-attributes.twig' => array(
                array('product.details.page.tab.description', 'customer'),
                array('product.details.page.info', 24, 'customer'),
            ),
            'product/details/parts/common.stock.twig' => array(
                array('product.details.page.info', 'customer'),
                array('product.details.page.info', 50, 'customer'),
            ),
            'items_list/product/parts/common.labels.twig' => array(
                array('itemsList.product.grid.customer.info', 'customer'),
                array('itemsList.product.grid.customer.info.photo', 100, 'customer'),
            ),
        );
    }

    /**
     * Decorator run this method at the end of cache rebuild
     *
     * @return void
     */
    public static function runBuildCacheHandler()
    {
        parent::runBuildCacheHandler();

        \XLite\Core\Layout::getInstance()->removeTemplateFromList(
            'layout/header/header.bar.search.twig',
            'layout.header.bar',
            \XLite\Model\ViewList::INTERFACE_CUSTOMER
        );
        \XLite\Core\Layout::getInstance()->addTemplateToList(
            'layout/header/header.bar.search.twig',
            'sidebar.single',
            array(
                'zone'   => \XLite\Model\ViewList::INTERFACE_CUSTOMER,
                'weight' => 105,
            )
        );
        \XLite\Core\Layout::getInstance()->addTemplateToList(
            'layout/header/header.bar.search.twig',
            'sidebar.first',
            array(
                'zone'   => \XLite\Model\ViewList::INTERFACE_CUSTOMER,
                'weight' => 105,
            )
        );

        \XLite\Core\Layout::getInstance()->addClassToList(
            'XLite\View\Minicart',
            'sidebar.single',
            array(
                'zone'   => \XLite\Model\ViewList::INTERFACE_CUSTOMER,
                'weight' => 120,
            )
        );
        \XLite\Core\Layout::getInstance()->addClassToList(
            'XLite\View\Minicart',
            'sidebar.first',
            array(
                'zone'   => \XLite\Model\ViewList::INTERFACE_CUSTOMER,
                'weight' => 120,
            )
        );

        if (static::isModuleEnabled('Bestsellers', 'CDev')) {
            \XLite\Core\Layout::getInstance()->removeClassFromList(
                'XLite\Module\CDev\Bestsellers\View\Bestsellers',
                'center.bottom',
                \XLite\Model\ViewList::INTERFACE_CUSTOMER
            );
            \XLite\Core\Layout::getInstance()->addClassToList(
                'XLite\Module\CDev\Bestsellers\View\Bestsellers',
                'content.bottom',
                array(
                    'zone'   => \XLite\Model\ViewList::INTERFACE_CUSTOMER,
                    'weight' => 200,
                )
            );
        }

        if (static::isModuleEnabled('ProductAdvisor', 'CDev')) {
            \XLite\Core\Layout::getInstance()->removeClassFromList(
                'XLite\Module\CDev\ProductAdvisor\View\NewArrivals',
                'sidebar.single',
                \XLite\Model\ViewList::INTERFACE_CUSTOMER
            );
            \XLite\Core\Layout::getInstance()->addClassToList(
                'XLite\Module\CDev\ProductAdvisor\View\NewArrivals',
                'content.bottom',
                array(
                    'zone'   => \XLite\Model\ViewList::INTERFACE_CUSTOMER,
                    'weight' => 150,
                )
            );
        }

        if (static::isModuleEnabled('News', 'XC')) {
            \XLite\Core\Layout::getInstance()->removeClassFromList(
                'XLite\Module\XC\News\View\TopNewsSideBar',
                'sidebar.first',
                \XLite\Model\ViewList::INTERFACE_CUSTOMER
            );
            \XLite\Core\Layout::getInstance()->removeClassFromList(
                'XLite\Module\XC\News\View\TopNewsSideBar',
                'sidebar.single',
                \XLite\Model\ViewList::INTERFACE_CUSTOMER
            );
            \XLite\Core\Layout::getInstance()->addClassToList(
                'XLite\Module\XC\News\View\TopNewsSideBar',
                'content.bottom',
                array(
                    'zone'   => \XLite\Model\ViewList::INTERFACE_CUSTOMER,
                    'weight' => 100,
                )
            );
        }
    }
}
