<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * X-Cart
 *
 * NOTICE OF LICENSE
 *
 * This source file is subject to the software license agreement
 * that is bundled with this package in the file LICENSE.txt.
 * It is also available through the world-wide-web at this URL:
 * http://www.x-cart.com/license-agreement.html
 * If you did not receive a copy of the license and are unable to
 * obtain it through the world-wide-web, please send an email
 * to licensing@x-cart.com so we can send you a copy immediately.
 *
 * DISCLAIMER
 *
 * Do not modify this file if you wish to upgrade X-Cart to newer versions
 * in the future. If you wish to customize X-Cart for your needs please
 * refer to http://www.x-cart.com/ for more information.
 *
 * @category  X-Cart 5
 * @author    Qualiteam software Ltd <info@x-cart.com>
 * @copyright Copyright (c) 2011-2014 Qualiteam software Ltd <info@x-cart.com>. All rights reserved
 * @license   http://www.x-cart.com/license-agreement.html X-Cart 5 License Agreement
 * @link      http://www.x-cart.com/
 */

namespace XLite\Module\QSL\VitalitySkin\View;

abstract class AView extends \XLite\View\AView implements \XLite\Base\IDecorator
{
    protected function isHomePage()
    {
        if ($this->getTarget() == 'main') {
            return true;
        } else {
            return false;
        }
    }

    protected function getThemeFiles($adminZone = null)
    {
        $list = parent::getThemeFiles($adminZone);

        if (!(is_null($adminZone) ? \XLite::isAdminZone() : $adminZone)) {
            $list[static::RESOURCE_CSS][] = 'css/altskin.css';
        }

        return $list;
    }

     /**
     * Determines if some module is enabled
     *
     * @return boolean
     */
    public function isModuleEnabled($moduleName, $moduleAuthor = 'CDev')
    {
        $module = \XLite\Core\Database::getRepo('XLite\Model\Module')
            ->findOneBy(array('author' => $moduleAuthor, 'name' => $moduleName));
        return $module && $module->getEnabled();
    }

    /**
     * Is there some top news
     *
     * @return boolean
     */
    protected function isTopNews()
    {
        if (!$this->isModuleEnabled('News', 'XC')) {
            return false;
        }

        $cnd = new \XLite\Core\CommonCell;
        $cnd->{\XLite\Module\XC\News\Model\Repo\NewsMessage::SEARCH_ENABLED} = true;
        $count = \XLite\Core\Database::getRepo('XLite\Module\XC\News\Model\NewsMessage')->search($cnd, true);

        $result = $count > 0;

        return $result;
    }

    /**
     * Is there bestsellers
     *
     * @return boolean
     */
    protected function isBestsellers()
    {
        if (!$this->isModuleEnabled('Bestsellers', 'CDev')) {
            return false;
        }

        $cnd = new \XLite\Core\CommonCell();

        $bestsellers = new \XLite\Module\CDev\Bestsellers\View\Bestsellers();
        //$bestsellers = $bestsellers->getData($cnd);

        return !empty($bestsellers);
    }
}
