<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Module\Qualiteam\BopfAdditionalCheckoutFields\Model;

/**
 * Class represents an order
 */
class Order extends \XLite\Model\Order implements \XLite\Base\IDecorator
{
    /**
     * Order details
     *
     * @var \Doctrine\Common\Collections\Collection
     *
     * @OneToMany (targetEntity="XLite\Module\Qualiteam\BopfAdditionalCheckoutFields\Model\OrderAdditionalFields", mappedBy="order", cascade={"all"})
     * @OrderBy   ({"label" = "ASC"})
     */
    protected $additional_fields;

    /**
     * Constructor
     *
     * @param array $data Entity properties OPTIONAL
     */
    public function __construct(array $data = array())
    {
        $this->additional_fields = new \Doctrine\Common\Collections\ArrayCollection();

        parent::__construct($data);
    }

    /**
     * Add additional fields
     *
     * @param \XLite\Module\Qualiteam\BopfAdditionalCheckoutFields\Model\OrderAdditionalFields $additional_fields
     * @return Order
     */
    public function addAdditionalFields(\XLite\Module\Qualiteam\BopfAdditionalCheckoutFields\Model\OrderAdditionalFields $additional_fields)
    {
        $this->additional_fields[] = $additional_fields;
        return $this;
    }

    /**
     * Get additional fields
     *
     * @return \Doctrine\Common\Collections\Collection
     */
    public function getAdditionalFields()
    {
        return $this->additional_fields;
    }

    /*
     * Get additional field by name
     */
    public function getAdditionalFieldByName($fieldName)
    {
        $result = null;

        if ($fieldName) {
            $fields = $this->getAdditionalFields();

            if ($fields) {
                foreach ($fields as $field) {
                    if ($field->getName() == $fieldName) {
                        $result = $field;

                        break;
                    }
                }
            }
        }

        return $result;
    }
}
