<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Module\Qualiteam\FreeCatalogFeatureT57432\Logic\Export\Step;

use XLite\Module\Qualiteam\FreeCatalogFeatureT57432\Logic\Export\Generator;
use XLite\Module\Qualiteam\FreeCatalogFeatureT57432\Model\CatalogRequest;

/**
 * Subscribers
 */
class CatalogRequests extends \XLite\Logic\Export\Step\AStep
{

    /**
     * Constructor
     *
     * @param \XLite\Logic\Export\Generator $generator Generator
     */
    public function __construct(\XLite\Logic\Export\Generator $generator = null)
    {
        parent::__construct($generator);

        if ($generator) {
            $name = $this->getFilename();
            if ('.csv' != substr($name, -4)) {
                $name .= '.csv';
            }
            $name = preg_replace('/(\.[^\.]+)$/', '-' . date('Y-m-d') . '$1', $name);
            /** @var Generator $generator */
            $generator->setFileInProcess($name);
        }
    }

    // {{{ Data

    /**
     * Get repository
     *
     * @return \XLite\Model\Repo\ARepo
     */
    protected function getRepository()
    {
        return \XLite\Core\Database::getRepo('XLite\Module\Qualiteam\FreeCatalogFeatureT57432\Model\CatalogRequest');
    }


    /**
     * Get filename
     *
     * @return string
     */
    protected function getFilename()
    {
        $value = $this->generator->getOptions()->file_suffix
            ?: 'default';

        return "catalog_requests_$value.csv";
    }

    // }}}

    // {{{ Columns

    /**
     * Define columns
     *
     * @return array
     */
    protected function defineColumns()
    {
        return [
            'name'      => [static::COLUMN_GETTER => 'getNameColumnValue'],
            'address 1' => [static::COLUMN_GETTER => 'getAddress1ColumnValue'],
            'address 2' => [static::COLUMN_GETTER => 'getAddress2ColumnValue'],
            'city'      => [static::COLUMN_GETTER => 'getCityColumnValue'],
            'state'     => [static::COLUMN_GETTER => 'getStateColumnValue'],
            'zipcode'   => [static::COLUMN_GETTER => 'getZipCodeColumnValue'],
            'code'      => [static::COLUMN_GETTER => 'getHowDidYouFindUsCodeColumnValue'],
            'email'     => [static::COLUMN_GETTER => 'getEmailColumnValue'],
        ];
    }

    // }}}

    // {{{ Getters and formatters

    /**
     * @param array   $dataset Dataset
     * @param string  $name    Column name
     * @param integer $i       Subcolumn index
     *
     * @return string
     */
    protected function getNameColumnValue(array $dataset, $name, $i)
    {
        return $this->getModel($dataset)->getName();
    }

    /**
     * @param array   $dataset Dataset
     * @param string  $name    Column name
     * @param integer $i       Subcolumn index
     *
     * @return string
     */
    protected function getAddress1ColumnValue(array $dataset, $name, $i)
    {
        return $this->getModel($dataset)->getStreetAddress();
    }

    /**
     * @param array   $dataset Dataset
     * @param string  $name    Column name
     * @param integer $i       Subcolumn index
     *
     * @return string
     */
    protected function getAddress2ColumnValue(array $dataset, $name, $i)
    {
        return $this->getModel($dataset)->getPoBox();
    }

    /**
     * @param array   $dataset Dataset
     * @param string  $name    Column name
     * @param integer $i       Subcolumn index
     *
     * @return string
     */
    protected function getCityColumnValue(array $dataset, $name, $i)
    {
        return $this->getModel($dataset)->getCity();
    }

    /**
     * @param array   $dataset Dataset
     * @param string  $name    Column name
     * @param integer $i       Subcolumn index
     *
     * @return string
     */
    protected function getStateColumnValue(array $dataset, $name, $i)
    {
        return $this->getModel($dataset)->getState();
    }

    /**
     * @param array   $dataset Dataset
     * @param string  $name    Column name
     * @param integer $i       Subcolumn index
     *
     * @return string
     */
    protected function getZipCodeColumnValue(array $dataset, $name, $i)
    {
        return $this->getModel($dataset)->getZipCode();
    }

    /**
     * @param array   $dataset Dataset
     * @param string  $name    Column name
     * @param integer $i       Subcolumn index
     *
     * @return string
     */
    protected function getHowDidYouFindUsCodeColumnValue(array $dataset, $name, $i)
    {
        return $this->getModel($dataset)->getHowDidYouFindUs();
    }

    /**
     * @param array   $dataset Dataset
     * @param string  $name    Column name
     * @param integer $i       Subcolumn index
     *
     * @return string
     */
    protected function getEmailColumnValue(array $dataset, $name, $i)
    {
        return $this->getModel($dataset)->getEmailAddress();
    }

    /**
     * @param array $dataset
     *
     * @return \XLite\Module\Qualiteam\FreeCatalogFeatureT57432\Model\CatalogRequest
     */
    protected function getModel(array $dataset)
    {
        return $dataset['model'];
    }

    // }}}

    /**
     * Process model
     *
     * @param \XLite\Model\AEntity $model Model
     *
     * @return void
     */
    protected function processModel(\XLite\Model\AEntity $model)
    {
        parent::processModel($model);

        if ($model) {
            /** @var CatalogRequest $model */
            $model->setExported(true);
        }
    }
}
