<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Module\Qualiteam\FreeCatalogFeatureT57432\Model;


/**
 * CatalogRequest
 *
 * @Entity
 * @Table  (name="catalog_request")
 */
class CatalogRequest extends \XLite\Model\AEntity
{
    /**
     * @var integer
     *
     * @Id
     * @GeneratedValue (strategy="AUTO")
     * @Column         (type="integer")
     */
    protected $id;

    /**
     * @var string
     *
     * @Column (type="string", length=255)
     */
    protected $name = '';

    /**
     * @var string
     *
     * @Column (type="string", length=255)
     */
    protected $street_address = '';

    /**
     * @var string
     *
     * @Column (type="string", length=255)
     */
    protected $po_box = '';

    /**
     * @var string
     *
     * @Column (type="string", length=255)
     */
    protected $city = '';

    /**
     * @var string
     *
     * @Column (type="string", length=255)
     */
    protected $state = '';

    /**
     * @var string
     *
     * @Column (type="string", length=255)
     */
    protected $zip_code = '';

    /**
     * @var string
     *
     * @Column (type="string", length=255)
     */
    protected $email_address = '';

    /**
     * @var string
     *
     * @Column (type="string", length=255)
     */
    protected $how_did_you_find_us = '';

    /**
     * @var boolean
     *
     * @Column (type="boolean", options={ "default": false })
     */
    protected $exported = false;

    /**
     * Flag to exporting entities
     *
     * @var boolean
     *
     * @Column (type="boolean")
     */
    protected $xcPendingExport = false;

    /**
     * @return int
     */
    public function getId()
    {
        return $this->id;
    }

    /**
     * @return string
     */
    public function getName()
    {
        return $this->name;
    }

    /**
     * @param string $name
     */
    public function setName($name)
    {
        $this->name = $name;
    }

    /**
     * @return string
     */
    public function getStreetAddress()
    {
        return $this->street_address;
    }

    /**
     * @param string $street_address
     */
    public function setStreetAddress($street_address)
    {
        $this->street_address = $street_address;
    }

    /**
     * @return string
     */
    public function getPoBox()
    {
        return $this->po_box;
    }

    /**
     * @param string $po_box
     */
    public function setPoBox($po_box)
    {
        $this->po_box = $po_box;
    }

    /**
     * @return string
     */
    public function getCity()
    {
        return $this->city;
    }

    /**
     * @param string $city
     */
    public function setCity($city)
    {
        $this->city = $city;
    }

    /**
     * @return string
     */
    public function getState()
    {
        return $this->state;
    }

    /**
     * @param string $state
     */
    public function setState($state)
    {
        $this->state = $state;
    }

    /**
     * @return string
     */
    public function getStateName()
    {
        if (!$this->state) {
            return '';
        }

        /** @var \XLite\Model\Repo\State $repo */
        $repo = \XLite\Core\Database::getRepo('XLite\Model\State');
        $state = $repo->findOneByCountryAndState(
            'US',
            $this->state
        );

        if (!$state) {
            return '';
        }

        /** @var \XLite\Model\State $state */
        return $state->getState();
    }

    /**
     * @return string
     */
    public function getZipCode()
    {
        return $this->zip_code;
    }

    /**
     * @param string $zip_code
     */
    public function setZipCode($zip_code)
    {
        $this->zip_code = $zip_code;
    }

    /**
     * @return string
     */
    public function getEmailAddress()
    {
        return $this->email_address;
    }

    /**
     * @param string $email_address
     */
    public function setEmailAddress($email_address)
    {
        $this->email_address = $email_address;
    }

    /**
     * @return string
     */
    public function getHowDidYouFindUs()
    {
        return $this->how_did_you_find_us;
    }

    /**
     * @return string
     */
    public function getHowDidYouFindUsHuman()
    {
        $map = static::getHowDidYouFindUsMap();

        return isset($map[$this->how_did_you_find_us])
            ? $map[$this->how_did_you_find_us]
            : $this->how_did_you_find_us;
    }

    /**
     * @param string $how_did_you_find_us
     */
    public function setHowDidYouFindUs($how_did_you_find_us)
    {
        $this->how_did_you_find_us = $how_did_you_find_us;
    }

    /**
     * @return bool
     */
    public function isExported()
    {
        return $this->exported;
    }

    /**
     * @param bool $exported
     */
    public function setExported($exported)
    {
        $this->exported = $exported;
    }

    public static function getHowDidYouFindUsMap()
    {
        return [
            'webref'=> 'Friend or Family Referral',
            'GM09'  => 'Card Pack',
            'cntry' => 'Countryside Magazine',
            'earth' => 'Mother Earth News',
            'MGA'   => 'Mailorder Gardening Association',
            'NGA'   => 'National Gardening Association',
            'web'   => 'Search Engine',
            'opweb' => 'Previous Customer',
            'other' => 'Other',
        ];
    }

    /**
     * @return bool
     */
    public function isXcPendingExport()
    {
        return $this->xcPendingExport;
    }

    /**
     * @param bool $xcPendingExport
     */
    public function setXcPendingExport($xcPendingExport)
    {
        $this->xcPendingExport = $xcPendingExport;
    }
}
