<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Module\Qualiteam\FreeCatalogFeatureT57432\View\ItemsList;

use XLite\Model\SearchCondition\Expression\TypeEquality;
use XLite\Model\SearchCondition\Expression\TypeLike;
use XLite\Model\SearchCondition\IExpressionProvider;

class CatalogRequests extends \XLite\View\ItemsList\Model\Table
{
    public function getCSSFiles()
    {
        $list = parent::getCSSFiles();
        $list[] = 'modules/Qualiteam/FreeCatalogFeatureT57432/items_list/style.css';
        return $list;
    }

    public function getJSFiles()
    {
        $list = parent::getJSFiles();
        $list[] = 'modules/Qualiteam/FreeCatalogFeatureT57432/items_list/controller.js';
        return $list;
    }

    /**
     * Get panel class
     *
     * @return string|\XLite\View\Base\FormStickyPanel
     */
    protected function getPanelClass()
    {
        return 'XLite\Module\Qualiteam\FreeCatalogFeatureT57432\View\StickyPanel\CatalogRequests';
    }

    /**
     * Should itemsList be wrapped with form
     *
     * @return boolean
     */
    protected function wrapWithFormByDefault()
    {
        return true;
    }

    /**
     * Return list of allowed targets
     *
     * @return array
     */
    public static function getAllowedTargets()
    {
        return array_merge(parent::getAllowedTargets(), array('catalog_request_export'));
    }

    /**
     * Define columns structure
     *
     * @return array
     */
    protected function defineColumns()
    {
        return [
            'name'                => [
                static::COLUMN_NAME => static::t('Name'),
            ],
            'street_address'      => [
                static::COLUMN_NAME => static::t('Street Address'),
            ],
            'po_box'              => [
                self::COLUMN_NAME => static::t('P.O. Box'),
            ],
            'city'                => [
                self::COLUMN_NAME => static::t('City'),
            ],
            'state_name'               => [
                self::COLUMN_NAME => static::t('State'),
            ],
            'zip_code'            => [
                self::COLUMN_NAME => static::t('Zip Code'),
            ],
            'email_address'       => [
                self::COLUMN_NAME => static::t('Email Address'),
            ],
            'how_did_you_find_us_human' => [
                self::COLUMN_NAME => static::t('How did you find us?'),
            ],
            'exported'            => [
                static::COLUMN_NAME => static::t('Is exported'),
            ],
        ];
    }

    /**
     * @param mixed                 $value  Value
     * @param array                 $column Column data
     * @param \XLite\Model\AEntity  $entity Entity
     *
     * @return string
     */
    protected function preprocessExported($value, array $column, \XLite\Model\AEntity $entity)
    {
        return $value
            ? static::t('Yes')
            : static::t('No');
    }

    /**
     * Define repository name
     *
     * @return string
     */
    protected function defineRepositoryName()
    {
        return 'XLite\Module\Qualiteam\FreeCatalogFeatureT57432\Model\CatalogRequest';
    }

    /**
     * Mark list as selectable
     *
     * @return boolean
     */
    protected function isSelectable()
    {
        return true;
    }

    /**
     * Get search panel widget class
     *
     * @return string
     */
    protected function getSearchPanelClass()
    {
        return 'XLite\View\SearchPanel\SimpleSearchPanel';
    }

    /**
     * Get search form options
     *
     * @return array
     */
    public function getSearchFormOptions()
    {
        return array(
            'target'    => 'catalog_request_export'
        );
    }

    /**
     * Get search case (aggregated search conditions) processor
     * This should be passed in here by the controller, but i don't see appropriate way to do so
     *
     * @return \XLite\View\ItemsList\ISearchCaseProvider
     */
    public static function getSearchCaseProcessor()
    {
        return new \XLite\View\ItemsList\SearchCaseProcessor(
            static::getSearchParams(),
            static::getSearchValuesStorage()
        );
    }

    /**
     * Default search conditions
     *
     * @param  \XLite\Core\CommonCell $searchCase Search case
     *
     * @return \XLite\Core\CommonCell
     */
    protected function postprocessSearchCase(\XLite\Core\CommonCell $searchCase)
    {
        if (isset($searchCase->state) && $searchCase->state instanceof IExpressionProvider) {
            /** @var IExpressionProvider $value */
            $value = $searchCase->state;
            /** @var \XLite\Model\State $state */
            $state = \XLite\Core\Database::getRepo('XLite\Model\State')->find(
                $value->getValue()
            );

            if ($state && method_exists($value, 'setValue')) {
                $value->setValue($state->getCode());
                $searchCase->state =$value;
            } else {
                unset($searchCase->state);
            }
        }

        if (isset($searchCase->exported) && $searchCase->exported instanceof IExpressionProvider) {
            /** @var IExpressionProvider $value */
            $value = $searchCase->exported;

            $realValue = $value->getValue();
            if ($realValue === 'exported' || $realValue === 'not_exported') {
                if (method_exists($value, 'setValue')) {
                    $value->setValue($realValue === 'exported');
                    $searchCase->state =$value;
                } else {
                    unset($searchCase->state);
                }
            } else {
                unset($searchCase->state);
            }
        }

        return $searchCase;
    }

    /**
     * Return search parameters.
     *
     * @return array
     */
    public static function getSearchParams()
    {
        return array_merge(
            parent::getSearchParams(),
            [
                'name'    => [
                    'condition'         => new TypeLike('name'),
                    'widget'            => [
                        \XLite\View\SearchPanel\ASearchPanel::CONDITION_CLASS   => 'XLite\View\FormField\Input\Text',
                        \XLite\View\FormField\Input\Text::PARAM_PLACEHOLDER     => static::t('Name'),
                    ],
                ],
                'email'    => [
                    'condition'         => new TypeLike('email_address'),
                    'widget'            => [
                        \XLite\View\SearchPanel\ASearchPanel::CONDITION_CLASS   => 'XLite\View\FormField\Input\Text',
                        \XLite\View\FormField\Input\Text::PARAM_PLACEHOLDER     => static::t('Email'),
                    ],
                ],
                'city'    => [
                    'condition'         => new TypeLike('city'),
                    'widget'            => [
                        \XLite\View\SearchPanel\ASearchPanel::CONDITION_CLASS   => 'XLite\View\FormField\Input\Text',
                        \XLite\View\FormField\Input\Text::PARAM_PLACEHOLDER     => static::t('City'),
                    ],
                ],
                'state'    => [
                    'condition'         => new TypeLike('state'),
                    'widget'            => [
                        \XLite\View\SearchPanel\ASearchPanel::CONDITION_CLASS   => 'XLite\View\FormField\Select\State',
                        \XLite\View\FormField\Input\Text::PARAM_PLACEHOLDER     => static::t('State'),
                        \XLite\View\FormField\Input\Text::PARAM_LABEL     => static::t('State'),
                        \XLite\View\FormField\Select\State::PARAM_COUNTRY => 'US',
                        \XLite\View\FormField\Select\State::PARAM_SELECT_ONE => true
                    ],
                ],
                'exported'    => [
                    'condition'         => new TypeEquality('exported'),
                    'widget'            => [
                        \XLite\View\FormField\Input\Text::PARAM_LABEL     => static::t('Exported'),
                        \XLite\View\SearchPanel\ASearchPanel::CONDITION_CLASS   => 'XLite\View\FormField\Select\Regular',
                        \XLite\View\FormField\Select\Regular::PARAM_OPTIONS => [
                            ''             => static::t('Any'),
                            'exported'     => static::t('Exported'),
                            'not_exported' => static::t('Not exported'),
                        ],
                        \XLite\View\FormField\Input\Text::PARAM_PLACEHOLDER     => static::t('Exported'),
                    ],
                ],
            ]
        );
    }
}
