<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Module\Qualiteam\GlobalDiscountsT60032\Model;

/**
 * Class Order
 * @package XLite\Module\Qualiteam\GlobalDiscountsT60032\Model
 */
class Order extends \XLite\Model\Order implements \XLite\Base\IDecorator
{
    /**
     * @var boolean
     */
    protected $forceSubtotalExcluding = false;

    /**
     * @return float
     */
    public function getSubtotal()
    {
        if ($this->forceSubtotalExcluding) {
            return $this->getSubtotalExcluding();
        }
        return parent::getSubtotal();
    }

    /**
     * @param bool $forceSubtotalExcluding
     */
    public function setForceSubtotalExcluding($forceSubtotalExcluding)
    {
        $this->forceSubtotalExcluding = $forceSubtotalExcluding;
    }

    /**
     * @return float
     */
    public function getSubtotalExcluding()
    {
        $subtotal = parent::getSubtotal();

        return $subtotal - $this->getExcludedItemsSubtotal();
    }

    /**
     * @return float
     */
    public function getExcludedItemsSubtotal()
    {
        $items = $this->getItems();

        $result = 0.0;
        foreach ($items as $item) {
            if($item
                && $item->getProduct()
                && $item->getProduct()->isApplyGlobalDiscounts() === false
            ) {
                $result += $item->getSubtotal();
            }
        }

        return $result;
    }
}
