/* vim: set ts=2 sw=2 sts=2 et: */

/**
 * Products list controller
 *
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

decorate(
  'ProductsListView',
  'postprocess',
  function (isSuccess, initial) {
    arguments.callee.previousMethod.apply(this, arguments);

    var self = this;

    if (isSuccess) {
      // Process click on 'Add to cart' buttons by AJAX
      jQuery('.add-to-cart', this.base).not('.link').each(
        function (index, elem) {
          jQuery(elem).unbind('click').click(function() {
            if (
              (
                typeof jQuery(this).closest('form').get(0) == 'undefined'
                && typeof jQuery(this).closest('tr').find('form').get(0) == 'undefined'
              )
              || (
                typeof jQuery(this).closest('form').get(0) != 'undefined'
                && jQuery(this).closest('form').get(0).validate()
              )
              || (
                typeof jQuery(this).closest('tr').find('form').get(0) != 'undefined'
                && jQuery(this).closest('tr').find('form').get(0).validate()
              )
            ) {
              var product = $(elem).closest('.product-cell').find('.product');
              if (!product.length) {
                product = $(elem).closest('.product-cell');
              }

              var pid = core.getValueFromClass(product, 'productid');
              var forceOptions = product.is('.need-choose-options');
              var btnStateHolder = $(elem).prop('disabled');

              if (pid && !self.isLoading) {
                $(elem).prop('disabled', true);
              }

              if (forceOptions) {
                $(elem).prop('disabled', btnStateHolder);
                self.openQuickLook(pid);
              } else {
                core.trigger('addToCartViaClick', {productId: pid});
                self.addToCart(elem)
                  .always(function () {
                    $(elem).prop('disabled', btnStateHolder);
                  });
              }
            }
          });
        }
      );
    }
  }
);

decorate(
  'ProductsListView',
  'droppableDrop',
  function (event, ui, tray) {
    if (
      typeof jQuery(ui.draggable.find('form')).get(0) == 'undefined'
      || jQuery(ui.draggable.find('form')).get(0).validate()
    ) {
      arguments.callee.previousMethod.apply(this, arguments);
    }
  }
);

decorate(
  'ProductsListView',
  'addToCart',
  function (elem) {
    elem = jQuery(elem);
    var pid = core.getValueFromClass(elem, 'productid');
    var xhr = new $.Deferred();
    var amount = 1;

    if (typeof jQuery(elem.parent('form')).find(':input[name=amount]').val() != 'undefined') {
      // 'Add to cart' button clicked
      amount = jQuery(elem.parent('form')).find(':input[name=amount]').val();
    } else if (typeof jQuery(elem.find('form')).find(':input[name=amount]').val() != 'undefined') {
      // Product dragged and dropped
      amount = jQuery(elem.find('form')).find(':input[name=amount]').val();
    } else if (typeof jQuery(elem).closest('tr').find('form').find(':input[name=amount]').val() != 'undefined') {
      // 'Add to cart' icon clicked (table view)
      amount = jQuery(elem).closest('tr').find('form').find(':input[name=amount]').val();
    }

    if (pid && !this.isLoading) {

      if (this)
        xhr = core.post(
          URLHandler.buildURL({ target: 'cart', action: 'add' }),
          _.bind(this.handleAddToCart, this),
          {
            target:     'cart',
            action:     'add',
            product_id: pid,
            amount:     amount
          },
          {
            rpc: true
          }
        );
    } else {
      xhr.reject();
    }

    return xhr;
  }
);

decorate(
  'ProductsListView',
  'openQuickLook',
  function (product_id) {
    var amount = 1;

    if (typeof jQuery(':input[id=amount' + product_id + ']').val() != 'undefined') {
      amount = jQuery(':input[id=amount' + product_id + ']').val();
    }

    this.focusOnFirstOption();
    return !popup.load(
      URLHandler.buildURL({
        target:      'quick_look',
        action:      '',
        product_id:  product_id,
        only_center: 1,
        amount:      amount
      }),
      function () {
        jQuery('.formError').hide();
      },
      50000
    );
  }
);