<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 *
 * CHANGES
 *
 * 5.3.0.1
 * - Replace quantity widget for quick look popup (to transfer 'amount' value)
 *
 * 5.3.0.2
 * - Added module settings form (for excluding categories from adding qty input box)
 * - Added qty input box to the 'List' and 'Table' product list views
 */

namespace XLite\Module\Qualiteam\BopfQtyFieldForCategoryPages;

/**
 * 'BopfQtyFieldForCategoryPages' module main class
 */
abstract class Main extends \XLite\Module\AModule
{
    /**
     * Author name
     *
     * @return string
     */
    public static function getAuthorName()
    {
        return 'Qualiteam';
    }

    /**
     * Module name
     *
     * @return string
     */
    public static function getModuleName()
    {
        return '#60234 - Quantity field for category pages';
    }

    /**
     * Module description
     *
     * @return string
     */
    public static function getDescription()
    {
        return '#60234 - Adding numeric text boxes for product qty to category pages';
    }

    /**
     * Get module major version
     *
     * @return string
     */
    public static function getMajorVersion()
    {
        return '5.3';
    }

    /**
     * Module version
     *
     * @return string
     */
    public static function getMinorVersion()
    {
        return '0';
    }

    /**
     * Get module build number (4th number in the version)
     *
     * @return string
     */
    public static function getBuildVersion()
    {
        return '3';
    }

    /**
     * Determines if we need to show settings form link
     *
     * @return boolean
     */
    public static function showSettingsForm()
    {
        return true;
    }

    /**
     * Actions that take place after redeploying the store.
     *
     * @return void
     */
    public static function runBuildCacheHandler()
    {
        /**
         * Add to cart button (product list page)
         */
        \XLite\Core\Layout::getInstance()->removeTemplateFromList(
            'items_list/product/parts/grid.button-add2cart-wrapper.twig',
            'itemsList.product.grid.customer.info',
            \XLite\Model\ViewList::INTERFACE_CUSTOMER
        );

        \XLite\Core\Layout::getInstance()->removeTemplateFromList(
            'items_list/product/parts/list.button-add2cart.twig',
            'itemsList.product.list.customer.info',
            \XLite\Model\ViewList::INTERFACE_CUSTOMER
        );

        /**
         * Replace quantity widget for quick look popup (to transfer 'amount' value)
         */
        \XLite\Core\Layout::getInstance()->removeTemplateFromList(
            'product/details/parts/common.qty.twig',
            'product.details.quicklook.info.buttons.cart-buttons',
            \XLite\Model\ViewList::INTERFACE_CUSTOMER
        );

        \XLite\Core\Layout::getInstance()->removeTemplateFromList(
            'product/details/parts/common.qty.twig',
            'product.details.quicklook.info.buttons-added.cart-buttons',
            \XLite\Model\ViewList::INTERFACE_CUSTOMER
        );
    }
}
