<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Module\Qualiteam\FreeCatalogFeatureT57432\View\Model;

use XLite\Module\Qualiteam\FreeCatalogFeatureT57432\Model\CatalogRequest;

class CatalogRequestFormModel  extends \XLite\View\Model\AModel
{
    /**
     * Schema default
     *
     * @var array
     */
    protected $schemaDefault = array(
        'name' => array(
            self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Text',
            self::SCHEMA_LABEL    => 'Name',
            self::SCHEMA_REQUIRED => true,
        ),
        'street_address' => array(
            self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Text',
            self::SCHEMA_LABEL    => 'Street Address',
            self::SCHEMA_REQUIRED => true,
        ),
        'po_box' => array(
            self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Text',
            self::SCHEMA_LABEL    => 'P.O. Box',
            self::SCHEMA_REQUIRED => false,
        ),
        'city' => array(
            self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Text',
            self::SCHEMA_LABEL    => 'City',
            self::SCHEMA_REQUIRED => true,
        ),
        'state' => array(
            self::SCHEMA_CLASS    => 'XLite\View\FormField\Select\State',
            self::SCHEMA_LABEL    => 'State',
            self::SCHEMA_REQUIRED => true,
            \XLite\View\FormField\Select\State::PARAM_COUNTRY => 'US',
            \XLite\View\FormField\Select\State::PARAM_SELECT_ONE => true
        ),
        'zip_code' => array(
            self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Text',
            self::SCHEMA_LABEL    => 'Zip Code',
            self::SCHEMA_REQUIRED => true,
        ),
        'email_address' => array(
            self::SCHEMA_CLASS    => 'XLite\View\FormField\Input\Text\Email',
            self::SCHEMA_LABEL    => 'Email Address',
            self::SCHEMA_REQUIRED => false,
        ),
        'how_did_you_find_us' => array(
            self::SCHEMA_CLASS    => 'XLite\Module\Qualiteam\FreeCatalogFeatureT57432\View\FormField\Select\HowDidYouFindUs',
            self::SCHEMA_LABEL    => 'How did you find us?',
            self::SCHEMA_REQUIRED => false,
        ),
    );

    public function getCSSFiles()
    {
        $list = parent::getCSSFiles();
        $list[] = 'modules/Qualiteam/FreeCatalogFeatureT57432/model/style.css';
        return $list;
    }

    protected function getContainerClass()
    {
        return parent::getContainerClass() . ' free-catalog-request-form-model';
    }

    /**
     * This object will be used if another one is not passed
     *
     * @return CatalogRequest
     */
    protected function getDefaultModelObject()
    {
        $defaultData = [];

        $auth = \XLite\Core\Auth::getInstance();

        if ($auth->isLogged()
            && $auth->getProfile()
            && $auth->getProfile()->getBillingAddress()
        ) {
            $address = $auth->getProfile()->getBillingAddress();

            $defaultData = [
                'name'          => $address->getName(),
                'email_address' => $auth->getProfile()->getEmail()
            ];

            $isUsa = strtolower($address->getCountryCode()) === 'us';

            if ($isUsa) {
                $defaultData = array_merge(
                    $defaultData,
                    [
                        'street_address' => $address->getterProperty('street'),
                        'city' => $address->getterProperty('city'),
                        'state' => $address->getStateId(true),
                        'zip_code' => $address->getterProperty('zipcode'),
                    ]
                );
            }
        }

        // $how_did_you_find_us?
        // $pobox?
        return new CatalogRequest($defaultData);
    }

    /**
     * Return name of web form widget class
     *
     * @return string
     */
    protected function getFormClass()
    {
        return '\XLite\Module\Qualiteam\FreeCatalogFeatureT57432\View\Form\Model\CatalogRequest';
    }

    /**
     * Return list of the "Button" widgets
     *
     * @return array
     */
    protected function getFormButtons()
    {
        $result = parent::getFormButtons();

        $label = $this->getModelObject()->isPersistent() ? 'Update' : 'Create';

        $result['submit'] = new \XLite\View\Button\Submit(
            array(
                \XLite\View\Button\AButton::PARAM_LABEL    => $label,
                \XLite\View\Button\AButton::PARAM_BTN_TYPE => 'regular-main-button',
                \XLite\View\Button\AButton::PARAM_STYLE    => 'action',
            )
        );

        return $result;
    }

    protected function prepareDataForMapping()
    {
        $data = parent::prepareDataForMapping();

        if (!empty($data['state'])) {
            $state = \XLite\Core\Database::getRepo('XLite\Model\State')->find($data['state']);

            if($state) {
                /** @var \XLite\Model\State $state */
                $data['state'] = $state->getCode();
            }
        }

        return $data;
    }

    /**
     * Add top message
     *
     * @return void
     */
    protected function addDataSavedTopMessage()
    {
        if ('create' !== $this->currentAction) {
            parent::addDataSavedTopMessage();

        } else {
            \XLite\Core\TopMessage::addInfo('Thank you for requesting information');
        }
    }

}
