<?php
// vim: set ts=4 sw=4 sts=4 et:

/**
 * Copyright (c) 2011-present Qualiteam software Ltd. All rights reserved.
 * See https://www.x-cart.com/license-agreement.html for license details.
 */

namespace XLite\Module\Qualiteam\GlobalDiscountsT60032\Logic\Import\Processor;


use XLite\Module\Qualiteam\GlobalDiscountsT60032\Model\Product;

 class Products extends \XLite\Module\XC\ProductTags\Logic\Import\Processor\Products implements \XLite\Base\IDecorator
{
    /**
     * Define columns
     *
     * @return array
     */
    protected function defineColumns()
    {
        $columns = parent::defineColumns();

        $columns['applyGlobalDiscounts'] = [];

        return $columns;
    }

    /**
     * Get messages
     *
     * @return array
     */
    public static function getMessages()
    {
        return parent::getMessages()
            + [
                'PRODUCT-GLOBAL-DISCOUNTS-FMT' => 'Wrong format of ApplyGlobalDiscounts value',
            ];
    }

    /**
     * Verify 'apply_global_discounts' value
     *
     * @param mixed $value  Value
     * @param array $column Column info
     *
     * @return void
     */
    protected function verifyApplyGlobalDiscounts($value, array $column)
    {
        if (!$this->verifyValueAsEmpty($value) && !$this->verifyValueAsBoolean($value)) {
            $this->addWarning('PRODUCT-GLOBAL-DISCOUNTS-FMT', ['column' => $column, 'value' => $value]);
        }
    }

    /**
     * Import 'apply_global_discounts' value
     *
     * @param \XLite\Model\Product $model  Product
     * @param mixed                $value  Value
     * @param array                $column Column info
     *
     * @return void
     */
    protected function importApplyGlobalDiscountsColumn(\XLite\Model\Product $model, $value, array $column)
    {
        /** @var Product $model */
        $model->setApplyGlobalDiscounts($this->normalizeValueAsBoolean($value));
    }
}
